require 'fileutils'
require 'logger'
require 'paint'
require 'pstore'

# The cli tool for rev. Revit process paths passed to it in order to create new
#       documents to review online. Each path passed is determined to be a file,
#       directory or git repo. In the case of the first two "Document" objects
#       are created as a simple wrapper around important info we need to pass to
#       the Rev API. In the case of the repo, we only use files from the latest
#       commit (or a passed commit hash) along with diffs for each. The iops are
#       grouped together and the api calls are made last (aside from creating
#       the rev). This allows us to have UI feedback (spinnys) that'll keep the
#       user informed about what's going on
#
# @author [brwnrclse]
#
module Reivt
  FileUtils.mkdir_p("#{Dir.home}/.reivt")

  REIVT_STORE = PStore.new("#{Dir.home}/.reivt/reivt.pstore")
  LOGGER = Logger.new(STDOUT)
  DEVLOGGER = Logger.new("#{Dir.home}/.reivt/reivt-dev.log")

  DEVLOGGER.datetime_format = '%Y-%m-%d %H:%M:%S '
  LOGGER.formatter = proc do |severity, _, _, msg|
    case severity
    when 'ERROR' then "\n#{Paint[severity, :red]}: #{msg}\n"
    when 'FATAL' then "\n#{Paint[severity, :red]}L #{msg}\n"
    else
      "\n#{msg}\n"
    end
  end
end

require 'reivt/api'
require 'reivt/auth'
require 'reivt/cli'
require 'reivt/document'
require 'reivt/exception'
require 'reivt/util'
require 'reivt/version'
