require 'graphql/client'
require 'graphql/client/http'

require 'pp'

# An extension of our main module Reivt
#
# @author [brwnrclse]
#
module Reivt
  # Intrface for rev API, connects local changes with our remote.
  #
  # @author [brwnrclse]
  #
  module RevAPI
    SCHEMA_PATH = "#{Dir.pwd}/lib/reivt/schema/schema.json".freeze
    ENDPOINT_URL = 'https://api.graph.cool/simple/v1/revwver'.freeze
    ENDPOINT = GraphQL::Client::HTTP.new(ENDPOINT_URL) do
      def headers(_context)
        auth_token = Reivt::REIVT_STORE.transaction do |store|
          store.fetch(:auth0_id, nil)
        end

        { 'Authorization': "Bearer #{auth_token}" }
      end
    end

    ID_TOKEN = Reivt::REIVT_STORE.transaction do |store|
      store.fetch(:user_id, nil)
    end

    unless File.exist?(SCHEMA_PATH)
      GraphQL::Client.dump_schema(ENDPOINT, SCHEMA_PATH)
    end

    SCHEMA = GraphQL::Client.load_schema(SCHEMA_PATH)
    CLIENT = GraphQL::Client.new(schema: SCHEMA, execute: ENDPOINT)

    # Raise any errors in the response data or simply return the data
    #
    # @param api_response [Obj] A nested object containing either data or errors
    #
    # @return [Array] A list containing the data and error object from the req
    #
    def self.retrieve(api_response)
      errors = api_response.errors
      data = api_response.data

      if data.nil?
        msg = errors.details[:data].map { |error| error['message'] }
        raise Reivt::GraphQLDataException, msg.join(",\n")
      else
        data
      end
    end
  end
end

require_relative 'api/mutations/document_create.mutation'
require_relative 'api/mutations/document_delete.mutation'
require_relative 'api/mutations/rev_create.mutation'
require_relative 'api/mutations/rev_delete.mutation'
require_relative 'api/mutations/user_create.mutation'
require_relative 'api/mutations/user_signin.mutation'
