# An extension of our main module Revit
#
# @author [brwnrclse]
#
module Reivt
  # An extension of the RevAPI module
  #
  # @author [brwnrclse]
  #
  module RevAPI
    CreateDocumentMutation = CLIENT.parse <<-'GRAPHQL'
      mutation($blob: String!, $content_type: String!, $doc_name: String!, $has_diff: Boolean!, $rev_id: ID!) {
        createDocument(blob: $blob, contentType: $content_type, name: $doc_name, hasDiff: $has_diff, revId: $rev_id) {
          id
        }
      }
    GRAPHQL

    # API call to createDocument
    # @param blob [String] The contents of the Document
    # @param content_type [String] The kind of Document
    # @param doc_name [String] The name of the Document
    # @param rev_id [String] The id of the Rev this Document belongs to
    #
    # @return [String] The id of the Document
    #
    def self.create_doc(blob, content_type, doc_name, has_diff, rev_id)
      blob = "That's all folks?" if blob.nil? || blob.strip.empty?
      doc_name = 'Empty Doc' if doc_name.nil? || doc_name.strip.empty?
      has_diff = false if has_diff.nil?

      if content_type.nil? || content_type.strip.empty?
        content_type = 'plain text'
      end

      if rev_id.length < 25
        raise Reivt::GraphQLValidationException, 'Missing rev id'
      end

      result = CLIENT.query(CreateDocumentMutation, variables: {
                              blob: blob, content_type: content_type,
                              doc_name: doc_name, has_diff: has_diff,
                              rev_id: rev_id
                            })
      data = RevAPI.retrieve(result)

      data.createDocument.id
    end
  end
end
