# An extension of our main module
#
# @author [brwnrclse]
#
module Reivt
  # Blueprint for Document objects
  #
  # @author [brwnrclse]
  #
  # @!attribute [rw] blob
  #   @return [String] The contents of the file
  #
  # @!attribute [rw] content_type
  #   @return [String] The type of content within the file
  #
  # @!attribute [rw] doc_name
  #   @return [Array<DocumentClass>] The name of the file
  #
  # @!attribute [rw] has_diff
  #   @return [Boolean] Whether or not the file will have a diff
  #
  class Document
    attr_accessor(:blob, :content_type, :doc_name, :name, :has_diff)

    def initialize(blob, content_type, doc_name, has_diff = false)
      @blob = blob
      @content_type = content_type
      @has_diff = has_diff
      @doc_name = doc_name
    end

    # Allows Documents objects to be compared using .eql? using their contents
    #       and file name.
    #
    # @param other [Rev::Document] The Document to compare to
    #
    # @return [Boolean] True if equal
    #                False if not equa
    #
    def eql?(other)
      self == other
    end

    # Allows Documents objects to be compared using hashes created from a
    #       logical and (&) between the files contents and name.
    #
    # @param other [Rev::Document] The Document to compare to
    #
    # @return [Fixnum] The & between file content and name
    #
    def hash
      @blob.hash & @doc_name.hash
    end

    # Allows Documents objects to be compared using == using their contents
    #       and file name.
    #
    # @param other [Rev::Document] The Document to compare to
    #
    # @return [Boolean] True if equal
    #                   False if not equa
    #
    def ==(other)
      @blob == other.blob && @doc_name == other.doc_name
    end
  end
end
